@@ -7,18 +7,37 @@ RDF::Query - An RDF query implementation of SPARQL/RDQL in Perl for use with RDF
 
 =head1 VERSION
 
-This document describes RDF::Query version 2.903_01.
+This document describes RDF::Query version 2.903_02.
 
 =head1 SYNOPSIS
 
- my $query = RDF::Query->new( $sparql );
+ # SPARQL SELECT Query
+ my $query = RDF::Query->new( 'SELECT * WHERE ...' );
  my $iterator = $query->execute( $model );
  while (my $row = $iterator->next) {
+   # $row is a HASHref containing variable name -> RDF Term bindings
    print $row->{ 'var' }->as_string;
  }
  
+ # SPARQL CONSTRUCT/DESCRIBE Query
+ my $query = RDF::Query->new( 'CONSTRUCT { ... } WHERE ...' );
+ my $iterator = $query->execute( $model );
+ while (my $st = $iterator->next) {
+   # $st is a RDF::Trine::Statement object representing an RDF triple
+   print $st->as_string;
+ }
+ 
+ # SPARQL ASK Query
+ my $query = RDF::Query->new( 'ASK WHERE ...' );
+ my $iterator = $query->execute( $model );
+ my $bool = $iterator->get_boolean;
+ if ($bool) {
+   print "Yes!\n";
+ }
+ 
+ # RDQL Query
  my $query = new RDF::Query ( $rdql, { lang => 'rdql' } );
- my @rows = $query->execute( $model );
+ my @rows = $query->execute( $model ); # in list context, returns all results
 
 =head1 DESCRIPTION
 
@@ -137,7 +156,7 @@ use RDF::Query::Plan;
 
 our ($VERSION, $DEFAULT_PARSER);
 BEGIN {
-	$VERSION		= '2.903_01';
+	$VERSION		= '2.903_02';
 	$DEFAULT_PARSER	= 'sparql11';
 }
 
@@ -357,7 +376,15 @@ sub prepare {
 =item C<execute ( $store, %args )>
 
 Executes the query using the specified RDF C<< $store >>. If called in a list
-context, returns an array of rows, otherwise returns an iterator.
+context, returns an array of rows, otherwise returns an L<RDF::Trine::Iterator>
+object. The iterator returned may be an instance of several subclasses of
+L<RDF::Trine::Iterator>:
+
+* A L<RDF::Trine::Iterator::Bindings> object is returned for query forms producing variable binding results (SELECT queries).
+
+* A L<RDF::Trine::Iterator::Graph> object is returned for query forms producing in an RDF graph result (DESCRIBE and CONSTRUCT queries).
+
+* A L<RDF::Trine::Iterator::Boolean> object is returned for query forms producing a true/false result (ASK queries).
 
 =cut
 
@@ -379,8 +406,9 @@ sub execute {
 
 =item C<< execute_plan ( $plan, $context ) >>
 
-Executes the query using the supplied ExecutionContext. If called in a list
-context, returns an array of rows, otherwise returns an iterator.
+Executes the query plan generated by the C<<prepare>> method using the supplied
+L<RDF::Query::ExecutionContext>> object. Return value(s) are the same as for the
+C<<execute>> method.
 
 =cut
 
