@@ -7,7 +7,7 @@ RDF::Query::Algebra::Aggregate - Algebra class for aggregate patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Aggregate version 2.903_01.
+This document describes RDF::Query::Algebra::Aggregate version 2.903_02.
 
 =cut
 
@@ -27,13 +27,16 @@ use RDF::Trine::Iterator qw(smap);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.903_01';
+	$VERSION	= '2.903_02';
 }
 
 ######################################################################
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Query::Algebra> class.
+
 =over 4
 
 =cut
