@@ -7,7 +7,7 @@ RDF::Query::Algebra::BasicGraphPattern - Algebra class for BasicGraphPattern pat
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::BasicGraphPattern version 2.903_01.
+This document describes RDF::Query::Algebra::BasicGraphPattern version 2.903_02.
 
 =cut
 
@@ -20,7 +20,7 @@ use base qw(RDF::Query::Algebra);
 
 use Data::Dumper;
 use Log::Log4perl;
-use Scalar::Util qw(refaddr reftype);
+use Scalar::Util qw(blessed refaddr reftype);
 use Carp qw(carp croak confess);
 use Time::HiRes qw(gettimeofday tv_interval);
 use RDF::Trine::Iterator qw(smap swatch);
@@ -30,13 +30,16 @@ use RDF::Trine::Iterator qw(smap swatch);
 our ($VERSION);
 my %AS_SPARQL;
 BEGIN {
-	$VERSION	= '2.903_01';
+	$VERSION	= '2.903_02';
 }
 
 ######################################################################
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Query::Algebra> class.
+
 =over 4
 
 =cut
@@ -81,6 +84,34 @@ sub triples {
 	return @$self;
 }
 
+=item C<< quads >>
+
+Returns a list of the (implicit) quads belonging to this BGP.
+
+=cut
+
+sub quads {
+	my $self	= shift;
+	my @triples	= $self->triples;
+	my @quads;
+	foreach my $t (@triples) {
+		my @nodes	= $t->nodes;
+		foreach my $i (0 .. 3) {
+			my $n	= $nodes[ $i ];
+			if (not blessed($n)) {
+				if ($i == 3) {
+					$nodes[ $i ]	= RDF::Trine::Node::Nil->new();
+				} else {
+					$nodes[ $i ]	= RDF::Query::Node::Variable->new();
+				}
+			}
+		}
+		my $st	= RDF::Trine::Statement::Quad->new( @nodes );
+		push(@quads, $st);
+	}
+	return @quads;
+}
+
 =item C<< sse >>
 
 Returns the SSE string for this alegbra expression.
