@@ -7,7 +7,7 @@ RDF::Query::Algebra::Clear - Algebra class for CLEAR operations
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Clear version 2.903_01.
+This document describes RDF::Query::Algebra::Clear version 2.903_02.
 
 =cut
 
@@ -32,18 +32,21 @@ our ($VERSION);
 my %TRIPLE_LABELS;
 my @node_methods	= qw(subject predicate object);
 BEGIN {
-	$VERSION	= '2.903_01';
+	$VERSION	= '2.903_02';
 }
 
 ######################################################################
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Query::Algebra> class.
+
 =over 4
 
 =cut
 
-=item C<new ( $graph )>
+=item C<new ( $graph [, $silent] )>
 
 Returns a new CLEAR structure.
 
@@ -52,10 +55,12 @@ Returns a new CLEAR structure.
 sub new {
 	my $class	= shift;
 	my $graph	= shift;
+	my $silent	= shift;
 	unless ($graph) {
+		throw RDF::Query::Error::MethodInvocationError -text => "A graph argument is required in RDF::Query::Algebra::Clear->new";
 		$graph	= RDF::Trine::Node::Nil->new;
 	}
-	return bless([$graph], $class);
+	return bless([$graph, $silent], $class);
 }
 
 =item C<< construct_args >>
@@ -67,7 +72,7 @@ will produce a clone of this algebra pattern.
 
 sub construct_args {
 	my $self	= shift;
-	return ($self->graph);
+	return ($self->graph, $self->silent);
 }
 
 =item C<< as_sparql >>
@@ -149,6 +154,15 @@ sub graph {
 	return $self->[0];
 }
 
+=item C<< silent >>
+
+=cut
+
+sub silent {
+	my $self	= shift;
+	return $self->[1];
+}
+
 1;
 
 __END__
