@@ -7,7 +7,7 @@ RDF::Query::Algebra::Minus - Algebra class for Minus patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Minus version 2.903_01.
+This document describes RDF::Query::Algebra::Minus version 2.903_02.
 
 =cut
 
@@ -26,13 +26,16 @@ use RDF::Trine::Iterator qw(smap sgrep swatch);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.903_01';
+	$VERSION	= '2.903_02';
 }
 
 ######################################################################
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Query::Algebra> class.
+
 =over 4
 
 =cut
