@@ -7,7 +7,7 @@ RDF::Query::Algebra::Service - Algebra class for SERVICE (federation) patterns
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::Service version 2.903_01.
+This document describes RDF::Query::Algebra::Service version 2.903_02.
 
 =cut
 
@@ -32,13 +32,16 @@ use RDF::Trine::Iterator qw(sgrep smap swatch);
 our ($VERSION, $BLOOM_FILTER_ERROR_RATE);
 BEGIN {
 	$BLOOM_FILTER_ERROR_RATE	= 0.1;
-	$VERSION	= '2.903_01';
+	$VERSION	= '2.903_02';
 }
 
 ######################################################################
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Query::Algebra> class.
+
 =over 4
 
 =cut
