@@ -7,10 +7,13 @@ RDF::Query::Plan::Distinct - Executable query plan for Distincts.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Distinct version 2.903_01.
+This document describes RDF::Query::Plan::Distinct version 2.903_02.
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Query::Plan> class.
+
 =over 4
 
 =cut
@@ -25,7 +28,7 @@ use base qw(RDF::Query::Plan);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.903_01';
+	$VERSION	= '2.903_02';
 }
 
 ######################################################################
