@@ -7,10 +7,13 @@ RDF::Query::Plan::Service - Executable query plan for remote SPARQL queries.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::Service version 2.903_01.
+This document describes RDF::Query::Plan::Service version 2.903_02.
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Query::Plan> class.
+
 =over 4
 
 =cut
@@ -34,7 +37,7 @@ use RDF::Query::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION		= '2.903_01';
+	$VERSION		= '2.903_02';
 }
 
 ######################################################################
