@@ -7,10 +7,13 @@ RDF::Query::Plan::ThresholdUnion - Executable query plan for unions.
 
 =head1 VERSION
 
-This document describes RDF::Query::Plan::ThresholdUnion version 2.903_01.
+This document describes RDF::Query::Plan::ThresholdUnion version 2.903_02.
 
 =head1 METHODS
 
+Beyond the methods documented below, this class inherits methods from the
+L<RDF::Query::Plan> class.
+
 =over 4
 
 =cut
@@ -30,7 +33,7 @@ use RDF::Query::ExecutionContext;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.903_01';
+	$VERSION	= '2.903_02';
 }
 
 ######################################################################
